starcluster.tests.mytestplugin.SetupClass3

Package starcluster :: Package tests :: Module mytestplugin :: Class SetupClass3 |
[hide private]
[frames] | no frames]

# Class SetupClass3

source code

Instance Methods | [hide private]
__init__(self, my_arg, my_other_arg, my_other_other_arg) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
run(self, nodes, master, user, shell, volumes) Run this plugin's setup routines | source code
Inherited from `clustersetup.ClusterSetup`: `on_add_node`, `on_remove_node`, `on_restart`, `on_shutdown` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, my_arg, my_other_arg, my_other_other_arg) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### run(self, nodes, master, user, shell, volumes) | source code
Run this plugin's setup routines This method gets executed after the default cluster setup routines have been performed Overrides: clustersetup.ClusterSetup.run (inherited documentation)